@@ -64,10 +64,17 @@ from setroubleshoot.util import *
 from setroubleshoot.html_util import html_to_text
 import re
 import dbus
-import report
-import report.io
-import report.io.GTKIO
-import report.accountmanager
+
+has_libreport = False
+try:
+    import report
+    import report.io
+    import report.io.GTKIO
+    import report.accountmanager
+    has_libreport = True
+except ImportError:
+    # Bug reporting won't be available
+    pass
 
 from gi.repository import Gio
 
@@ -278,7 +285,8 @@ class BrowserApplet:
         self.make_treeview()
         self.troubleshoot_visible = False
         self.current_alert = -1
-        self.accounts = report.accountmanager.AccountManager()
+        if has_libreport:
+            self.accounts = report.accountmanager.AccountManager()
 
     def get_current_alert(self):
         try:
@@ -541,7 +549,7 @@ class BrowserApplet:
             report_button.connect("clicked", self.fix_bug, alert.local_id, plugin.analysis_id)
             vbox.add(report_button)
 
-        elif plugin.report_bug:
+        elif plugin.report_bug and has_libreport:
             report_button = Gtk.Button()
             report_button.set_label(_("Report\nBug"))
             report_button.show()
